@@ -290,6 +290,27 @@ void init_sound_player(user_data_t* data)
   g_object_set(data->sound_player, "audio-sink", pulsesink, NULL);
 }
 
+void
+profilesx_dialog_size_changed(GdkScreen* screen,
+			      gpointer user_data)
+{
+  GdkGeometry geometry;
+  if(gdk_screen_get_width(gdk_display_get_default_screen(gdk_display_get_default())) < 800)
+  {
+    geometry.min_height = 680;
+    geometry.min_width = 480; 
+  }
+  else
+  {
+    geometry.min_height = 360;
+    geometry.min_width = 800; 
+  }
+  gtk_window_set_geometry_hints(GTK_WINDOW(user_data),
+				GTK_WIDGET(user_data),
+				&geometry,
+				GDK_HINT_MIN_SIZE);
+}
+
 osso_return_t execute(osso_context_t *osso,
 		      gpointer data,
 		      gboolean user_activated)
@@ -300,6 +321,11 @@ osso_return_t execute(osso_context_t *osso,
   user_data_t* app_data = g_new0(user_data_t, 1);
   init_sound_player(app_data);
   create_main_dialog(app_data, GTK_WINDOW(data));
+  profilesx_dialog_size_changed(gdk_display_get_default_screen(gdk_display_get_default()),
+				app_data->main_dialog);
+  g_signal_connect(gdk_display_get_default_screen(gdk_display_get_default()), 
+		   "size-changed", 
+		   G_CALLBACK(profilesx_dialog_size_changed), app_data->main_dialog); 
 
   gtk_widget_show_all(app_data->main_dialog);
   show_hide_delete_button(HILDON_TOUCH_SELECTOR(app_data->profiles_selector), 
@@ -311,7 +337,9 @@ osso_return_t execute(osso_context_t *osso,
     //ignored
   }
   gtk_widget_destroy(GTK_WIDGET(app_data->main_dialog));
+  g_warning("unref soundplayer\n");
   gst_object_unref(app_data->sound_player);
+  g_warning("unref list store\n");
   gst_object_unref(app_data->profiles_list_store);
   g_free(app_data);
   return OSSO_OK;
