@@ -21,6 +21,7 @@
 #include <libprofile.h>
 #include <keys_nokia.h>
 #include <gconf/gconf-client.h>
+#include <gio/gio.h>
 
 #define PROFILESX_SETTINGS_FILE "/.profilesx"
 #define GC_ROOT "/apps/maemo/profilesx"
@@ -49,20 +50,53 @@ load_icon_name(const gchar* profile_name)
 void
 store_icon_name(const gchar* profile_name, const gchar* icon_name)
 {
-
   GKeyFile* key_file;
   gchar* file_name;
-
   key_file = g_key_file_new();
   file_name = g_strconcat(g_get_home_dir(), PROFILESX_SETTINGS_FILE, NULL);
   g_key_file_load_from_file(key_file, file_name, G_KEY_FILE_NONE, NULL);
   if(icon_name!=NULL)
   {
-    g_key_file_set_string(key_file, profile_name, "icon", icon_name);
+    gchar* path = g_path_get_basename(icon_name);
+    if(g_strcmp0(path, icon_name) == 0)
+    {
+      g_key_file_set_string(key_file, profile_name, "icon", icon_name);
+    }
+    else
+    {
+      gchar* escaped_profile_name = gconf_escape_key(profile_name, -1);
+      gchar* old_icon_name = g_strdup_printf("%s.png", escaped_profile_name);
+      gchar* new_icon_path = g_build_filename("/home/user/.profiled/", old_icon_name, NULL);
+      if(g_file_test(new_icon_path, G_FILE_TEST_EXISTS))
+      {
+	g_unlink(new_icon_path);
+      }
+      GFile* source = g_file_new_for_path(icon_name);
+      GFile* dest = g_file_new_for_path(new_icon_path);
+      
+      g_file_copy(source, dest,
+		  G_FILE_COPY_NONE, NULL, NULL, NULL, NULL);
+      
+      g_object_unref(source);
+      g_object_unref(dest);
+      g_key_file_set_string(key_file, profile_name, "icon", new_icon_path);
+      g_free(new_icon_path);
+      g_free(old_icon_name);
+      g_free(escaped_profile_name);
+    }
   }
   else
   {
     g_key_file_remove_key(key_file, profile_name, "icon", NULL);
+    gchar* escaped_profile_name = gconf_escape_key(profile_name, -1);
+    gchar* old_icon_name = g_strdup_printf("%s.png", escaped_profile_name);
+    gchar* new_icon_path = g_build_filename("/home/user/.profiled/", old_icon_name);
+    if(g_file_test(new_icon_path, G_FILE_TEST_EXISTS))
+      g_unlink(new_icon_path);
+
+    g_free(new_icon_path);
+    g_free(old_icon_name);
+    g_free(escaped_profile_name);
   }
   gsize size;
   gchar* file_data = g_key_file_to_data(key_file, &size, NULL);
