@@ -253,15 +253,17 @@ void set_profile_status_icon_value(editor_data_t* data)
   if(icon_name!=NULL)
   {
     GtkWidget* image;
-    if(gtk_icon_theme_has_icon(gtk_icon_theme_get_default (), 
-			       icon_name))
+    GdkPixbuf* pixbuf = NULL;
+    gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+			     icon_name,
+			     18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+    if(!pixbuf)
     {
-      image = gtk_image_new_from_icon_name(icon_name, 18);
-    }
-    else
-    {
-      image = gtk_image_new_from_file(icon_name);
+      pixbuf = gdk_pixbuf_new_from_file_at_size(icon_name,
+						18, 18, NULL);
     }
+    image = gtk_image_new_from_pixbuf(pixbuf);
+    g_object_unref(pixbuf);
     gtk_button_set_image(GTK_BUTTON(data->iconButton), image);
   }
 }
@@ -676,6 +678,8 @@ load_custom_icon(GtkButton* button, gchar** icon_path)
     if(ret == GTK_RESPONSE_OK)
     {
       gchar* filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
+      if(*icon_path)
+	g_free(*icon_path);
       (*icon_path) = filename;
       GtkWidget* image = gtk_image_new_from_file(filename);
       gtk_button_set_image(button, image);
@@ -723,13 +727,37 @@ icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_loud), FALSE);
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_custom), FALSE);
 
-
-  gtk_button_set_image(GTK_BUTTON(icon_button_silent), gtk_image_new_from_icon_name(icon_name_silent, 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_home), gtk_image_new_from_icon_name(icon_name_home, 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_im), gtk_image_new_from_icon_name(icon_name_im, 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_outside), gtk_image_new_from_icon_name(icon_name_outside, 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_loud), gtk_image_new_from_icon_name(icon_name_loud, 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_custom), gtk_image_new_from_icon_name("general_folder", 18));
+  GdkPixbuf* pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+					       icon_name_silent,
+					       18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  
+  gtk_button_set_image(GTK_BUTTON(icon_button_silent), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
+  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				    icon_name_home,
+				    18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  gtk_button_set_image(GTK_BUTTON(icon_button_home), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
+  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				    icon_name_im,
+				    18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  gtk_button_set_image(GTK_BUTTON(icon_button_im), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
+  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				    icon_name_outside,
+				    18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  gtk_button_set_image(GTK_BUTTON(icon_button_outside), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
+  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				    icon_name_loud,
+				    18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  gtk_button_set_image(GTK_BUTTON(icon_button_loud), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
+  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				    "general_folder",
+				    18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+  gtk_button_set_image(GTK_BUTTON(icon_button_custom), gtk_image_new_from_pixbuf(pixbuf));
+  g_object_unref(pixbuf);
 
   gtk_box_pack_start(GTK_BOX(icon_box), icon_button_none, TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(icon_box), icon_button_silent, TRUE, TRUE, 0);
@@ -959,6 +987,12 @@ show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement
   if(ret == GTK_RESPONSE_OK)
   {
     save_profile_values(profile_name, data);
+    gchar* active_profile = profile_get_profile();
+    if(g_strcmp0(active_profile, profile_name)==0)
+    {
+      profile_set_profile(profile_name);
+    }
+    g_free(active_profile);
   }
   gtk_widget_destroy(dialog);
   gtk_list_store_clear(data->imTone);
